Package: mort
Title: Identifying Potential Mortalities and Expelled Tags in Aquatic
        Acoustic Telemetry Arrays
Version: 0.0.1
Authors@R: c(
    person("Rosie", "Smith", , "rosieluain@gmail.com", role = c("aut", "cre", "cph"),
           comment = c(ORCID = "0000-0003-2675-4452")),
    person("Heidi", "Swanson", role = "fnd")
  )
Description: A toolkit for identifying potential mortalities and expelled tags in aquatic acoustic telemetry arrays. 
    Designed for arrays with non-overlapping receivers. 
License: GPL (>= 3)
Encoding: UTF-8
URL: https://github.com/rosieluain/mort,
        https://rosieluain.github.io/mort/
BugReports: https://github.com/rosieluain/mort/issues
RoxygenNote: 7.2.3
LazyData: true
Imports: lubridate, methods, rlang
Suggests: ggplot2, knitr, plotly, rmarkdown, testthat (>= 3.0.0)
VignetteBuilder: knitr
Depends: R (>= 3.5.0)
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2023-09-02 17:53:51 UTC; rosie
Author: Rosie Smith [aut, cre, cph] (<https://orcid.org/0000-0003-2675-4452>),
  Heidi Swanson [fnd]
Maintainer: Rosie Smith <rosieluain@gmail.com>
Repository: CRAN
Date/Publication: 2023-09-04 09:00:02 UTC
Built: R 4.6.0; ; 2026-04-26 01:19:25 UTC; unix
