# Generated by roxygen2: do not edit by hand

export(backwards)
export(drift)
export(infrequent)
export(morts)
export(mortsplot)
export(residences)
export(resmax)
export(resmaxcml)
export(review)
export(season)
export(stationchange)
import(lubridate)
import(methods)
importFrom(lubridate,hms)
importFrom(lubridate,period_to_seconds)
importFrom(methods,is)
importFrom(rlang,.data)
importFrom(stats,na.omit)
importFrom(utils,setTxtProgressBar)
importFrom(utils,txtProgressBar)
